GraphQLQueryBuilder class

Main Dartpollo builder.

Constructors

GraphQLQueryBuilder(BuilderOptions builderOptions)
Creates a builder from BuilderOptions.

Properties

allowSyntaxErrors bool
Whether to allow syntax errors in input libraries.
no setter
buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
expectedOutputs List<String>
List FragmentDefinitionNode in fragments_glob. The generated output file.
final
formatOutput String Function(String code, Version languageVersion)
Function that determines how the generated code is formatted.
no setter
hashCode int
The hash code for this object.
no setterinherited
onBuild OnBuildQuery?
Callback fired when the generator processes a QueryDefinition.
getter/setter pair
options → GeneratorOptions
This generator options, gathered from build.yaml file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
clearAllCaches() → void
Clear all caches and reset performance statistics
getPerformanceStats() Map<String, dynamic>
Get comprehensive performance statistics from all optimization components
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readGraphQlFiles(BuildStep buildStep, String schema) Future<List<DocumentNode>>
read asset files
readGraphQlFilesWithCache(BuildStep buildStep, String schema) Future<List<DocumentNode>>
read asset files with caching and hash-based validation Uses streaming processing for large files automatically
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited