withPathExtension method
Creates a new context with an additional type added to the path
Implementation
GenerationContext withPathExtension(TypeName typeName) {
return copyWith(path: [...path, typeName]);
}
Creates a new context with an additional type added to the path
GenerationContext withPathExtension(TypeName typeName) {
return copyWith(path: [...path, typeName]);
}