SchemaContext class

Immutable context containing schema-related information and configuration. Provides schema, type visitor, and generator options for the generation process.

Constructors

SchemaContext({required DocumentNode schema, required TypeDefinitionNodeVisitor typeVisitor, required GeneratorOptions options})
const

Properties

availableTypes Set<String>
Returns all available type names
no setter
hashCode int
The hash code for this object.
no setterinherited
options → GeneratorOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema → DocumentNode
final
typeVisitor TypeDefinitionNodeVisitor
final

Methods

getType(String typeName) → TypeDefinitionNode?
Gets a type definition by name, returns null if not found
hasType(String typeName) bool
Validates that a specific type exists in the schema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void
Validates the schema context for consistency

Operators

operator ==(Object other) bool
The equality operator.
inherited