isClean property
bool
get
isClean
Returns true if the validation context is clean (no errors or warnings)
Implementation
bool get isClean => !hasErrors && !hasWarnings;
Returns true if the validation context is clean (no errors or warnings)
bool get isClean => !hasErrors && !hasWarnings;