LibraryDefinition class

Define a whole library file, the output of a single SchemaMap code generation.

Mixed-in types

Constructors

LibraryDefinition({required String basename, Iterable<QueryDefinition> queries = const [], Iterable<String> customImports = const [], SchemaMap? schemaMap})
Instantiate a library definition.

Properties

basename String
The output file basename.
final
customImports Iterable<String>
Any other custom package imports, defined in build.yaml.
final
hashCode int
The hash code for this object.
no setterinherited
namedProps Map<String, Object?>
no setteroverride
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
queries Iterable<QueryDefinition>
A list of queries.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaMap → SchemaMap?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited