FragmentProcessor class
Handles fragment processing logic including extraction and class generation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extractFragments(
SelectionSetNode? selectionSet, List< FragmentDefinitionNode> fragmentsCommon) → Set<FragmentDefinitionNode> - Extracts fragments from a selection set recursively, including nested fragments.
-
processFragments(
List< FragmentDefinitionNode> fragments, Context context) → List<FragmentClassDefinition> - Processes fragments and generates fragment class definitions.