BatchProcessingError class

Exception thrown when batch processing fails

Inheritance

Constructors

BatchProcessingError(String message, {int? batchSize, List<String>? failedDocuments, Object? originalError})

Properties

batchSize int?
final
failedDocuments List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
originalError Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited