optimization/streaming_file_processor library

Classes

StreamingFileProcessor
Advanced file processor that implements streaming and chunked processing for large GraphQL files to reduce memory usage and improve performance.