StreamingFileProcessor class
Advanced file processor that implements streaming and chunked processing for large GraphQL files to reduce memory usage and improve performance.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMemoryStats(
) → Map< String, dynamic> - Get memory usage statistics
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processLargeFile(
BuildStep buildStep, AssetId assetId, {int chunkSize = defaultChunkSize, bool enableMemoryMonitoring = true}) → Future< List< DocumentNode> > - Process a large file using streaming/chunked approach
-
processMultipleFiles(
BuildStep buildStep, List< AssetId> assetIds, {int chunkSize = defaultChunkSize, bool enableMemoryMonitoring = true}) → Future<List< DocumentNode> > - Process multiple files with streaming optimization
-
reset(
) → void - Reset all statistics and clear memory
-
toString(
) → String -
A string representation of this object.
inherited
-
writeStreamingOutput(
BuildStep buildStep, AssetId outputId, Stream< String> contentStream, {int bufferSize = defaultChunkSize}) → Future<void> - Generate streaming output for large generated content
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultChunkSize → const int
- Default chunk size for file processing (64KB)
- maxMemoryThreshold → const int
- Maximum memory usage threshold (10MB)