formatOutput property
Function that determines how the generated code is formatted.
The languageVersion is the version to parse the file with, but it may be
overridden using a language version comment in the file.
Implementation
@override
String Function(String code, Version languageVersion) get formatOutput =>
_defaultFormatOutput;