OnNewClassFoundCallback typedef
OnNewClassFoundCallback =
void Function(Context context)
Callback function type for handling new class discoveries during generation.
This callback is invoked whenever a new class needs to be generated during the GraphQL code generation process.
Implementation
typedef OnNewClassFoundCallback = void Function(Context context);