InputGenerator class
Generator responsible for creating input object class definitions from GraphQL input types. Handles input validation, type relationships, and annotations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createInputClassProperty(
{required ClassPropertyName fieldName, required TypeNode fieldType, required List< DirectiveNode> fieldDirectives, required Context context}) → ClassProperty - Creates a class property for input objects with proper type handling and annotations
-
generateInputClass(
InputObjectTypeDefinitionNode node, Context context) → ClassDefinition - Generates an input class definition from a GraphQL input object type definition node
-
generateInputProperties(
List< InputValueDefinitionNode> fields, Context context) → List<ClassProperty> - Generates input class properties from GraphQL input value definition nodes