GenerationService class
Service responsible for coordinating the code generation process.
This service orchestrates the generation of GraphQL client code by coordinating between schema operations, file operations, and various code generators.
Constructors
- GenerationService({required SchemaService schemaService, required FileService fileService})
- Creates a new GenerationService with the required dependencies.
Properties
- fileService → FileService
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaService → SchemaService
-
final
Methods
-
generateDefinitions(
{required String path, required DocumentNode document, required GeneratorOptions options, required SchemaMap schemaMap, required List< FragmentDefinitionNode> fragmentsCommon, required CanonicalVisitor canonicalVisitor}) → Iterable<QueryDefinition> - Generates query definitions from a single GraphQL document.
-
generateLibrary(
String path, List< DocumentNode> gqlDocs, GeneratorOptions options, SchemaMap schemaMap, List<FragmentDefinitionNode> fragmentsCommon) → LibraryDefinition - Generates a complete library definition from GraphQL documents.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited